@@ -476,10 +476,26 @@ void PocoDatabaseImpl::GenerateExpressions (Expressions& expressions, const ptim
 				const any& a = vt.second.first;
 				switch (GetCollectionTypeFromValue(a))
 				{
-					case 'n':	expr += (format(" %g") % any_cast<double>(a)).str() + vt.second.second; break;
-					case 'r':	expr += (format(" %g") % any_cast<Ratio>(a).m_numerator).str() + vt.second.second + (format("%g") % any_cast<Ratio>(a).m_denominator).str(); break;
-					case 't':	comment = any_cast<string>(a); break;
-					default:	break;
+					case 'n':
+					{
+						expr += (format(" %g%s") % any_cast<double>(a) % vt.second.second).str();
+						break;
+					}
+					case 'r':
+					{
+						expr += (format(" %g%s%g") % any_cast<Ratio>(a).m_numerator % vt.second.second % any_cast<Ratio>(a).m_denominator).str();
+						break;
+					}
+					case 't':
+					{
+						if (vt.second.second != "#")
+							expr += (format(" \"%s\"%s") % any_cast<string>(a) % vt.second.second).str();
+						else
+							comment = any_cast<string>(a);
+						break;
+					}
+					default:
+						break;
 				}
 			}
 			if (expr[0] == ' ')
