@@ -28,6 +28,11 @@ using namespace boost::program_options;
 #include "out_impl.h"
 #include "out_ftree.h"
 
+#ifdef USE_READLINE
+#include <readline/readline.h>
+#include <readline/history.h>
+#endif
+
 //=== OutputInteractive ====================================================
 OutputInteractive::OutputInteractive (const string& option_key)
 	: OutputImpl(option_key)
@@ -38,18 +43,45 @@ void OutputInteractive::Do (const Config& config, const Database& database) cons
 {
 	cout << "pdx " << VERSION << ", interactive mode (press q to quit)" << endl;
 
+#ifdef USE_READLINE
+	// disable auto-complete
+	rl_bind_key('\t', rl_abort);
+
+	// load the history file if we have one
+	clear_history();
+	const string& history_filename = config.GetConfigFile() + "_history";
+	read_history(history_filename.c_str());
+#endif
+
 	string line;
 	while (true)
 	{
+#ifdef USE_READLINE
+		char* buf = readline("> ");
+		if (!buf)
+		{
+			cout << endl;
+			break; // Ctrl-D
+		}
+		line = buf;
+		free(buf);
+#else
 		cout << "> ";
 		if (!getline(cin, line))
 			break;
+#endif
+
 		trim(line);
-		if (line == "q")
-			break;
 		if (line.empty())
 			continue;
 
+		if (line == "q" || line == ".q" || line == "quit" || line == "exit" || line == "bye")
+			break;
+
+#ifdef USE_READLINE
+		add_history(line.c_str());
+#endif
+
 		try
 		{
 			if (line[0] == '?')
@@ -81,4 +113,9 @@ void OutputInteractive::Do (const Config& config, const Database& database) cons
 			cerr << e.Message() << endl;
 		}
 	}
+
+#ifdef USE_READLINE
+	// store the history file
+	write_history(history_filename.c_str());
+#endif
 }
